Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(667)

Unified Diff: cc/trees/layer_tree_host_interface.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/trees/layer_tree_host_impl_unittest.cc ('k') | cc/trees/layer_tree_host_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/trees/layer_tree_host_interface.h
diff --git a/cc/trees/layer_tree_host_interface.h b/cc/trees/layer_tree_host_interface.h
index aa329d9ca3661f9d5ea07d633dabf82fae31bdda..46df97aaa860f1179fe6c3b839b649e20811da79 100644
--- a/cc/trees/layer_tree_host_interface.h
+++ b/cc/trees/layer_tree_host_interface.h
@@ -24,7 +24,7 @@ class LayerTree;
class LayerTreeDebugState;
class LayerTreeMutator;
class LayerTreeSettings;
-class OutputSurface;
+class CompositorFrameSink;
class SwapPromiseMonitor;
class TaskRunnerProvider;
class UIResourceManager;
@@ -77,22 +77,23 @@ class CC_EXPORT LayerTreeHostInterface {
// Sets whether the content is suitable to use Gpu Rasterization.
virtual void SetHasGpuRasterizationTrigger(bool has_trigger) = 0;
- // Visibility and OutputSurface -------------------------------
+ // Visibility and CompositorFrameSink -------------------------------
virtual void SetVisible(bool visible) = 0;
virtual bool IsVisible() const = 0;
- // Called in response to an OutputSurface request made to the client using
- // LayerTreeHostClient::RequestNewOutputSurface. The client will be informed
- // of the OutputSurface initialization status using DidInitializaOutputSurface
- // or DidFailToInitializeOutputSurface. The request is completed when the host
- // successfully initializes an OutputSurface.
- virtual void SetOutputSurface(
- std::unique_ptr<OutputSurface> output_surface) = 0;
-
- // Forces the host to immediately release all references to the OutputSurface,
- // if any. Can be safely called any time.
- virtual std::unique_ptr<OutputSurface> ReleaseOutputSurface() = 0;
+ // Called in response to an CompositorFrameSink request made to the client
+ // using LayerTreeHostClient::RequestNewCompositorFrameSink. The client will
+ // be informed of the CompositorFrameSink initialization status using
+ // DidInitializaCompositorFrameSink or DidFailToInitializeCompositorFrameSink.
+ // The request is completed when the host successfully initializes an
+ // CompositorFrameSink.
+ virtual void SetCompositorFrameSink(
+ std::unique_ptr<CompositorFrameSink> compositor_frame_sink) = 0;
+
+ // Forces the host to immediately release all references to the
+ // CompositorFrameSink, if any. Can be safely called any time.
+ virtual std::unique_ptr<CompositorFrameSink> ReleaseCompositorFrameSink() = 0;
// Frame Scheduling (main and compositor frames) requests -------
« no previous file with comments | « cc/trees/layer_tree_host_impl_unittest.cc ('k') | cc/trees/layer_tree_host_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698